==> blackfin-vdsp_1.2.2.zip: blackfin-vdsp/bf533/board_config.h <==
/*
 *  TOPPERS/JSP Kernel
 *      Toyohashi Open Platform for Embedded Real-Time Systems/
 *      Just Standard Profile Kernel
 * 
 *  Copyright (C) 2000-2003 by Embedded and Real-Time Systems Laboratory
 *                              Toyohashi Univ. of Technology, JAPAN
 *
 *  TOPPERS/JSP for Blackfin
 *
 *  Copyright (C) 2004 by Suikan
 *  Copyright (C) 2004 by Ujinosuke
 *
 *  L쌠҂́Cȉ (1)`(4) ̏CFree Software Foundation 
 *  ɂČ\Ă GNU General Public License  Version 2 ɋL
 *  qĂ𖞂ꍇɌC{\tgEFAi{\tgEFA
 *  ς̂܂ށDȉjgpEEρEĔzziȉC
 *  pƌĂԁj邱Ƃ𖳏ŋD
 *  (1) {\tgEFA\[XR[ȟ`ŗpꍇɂ́CL̒
 *      \C̗pщL̖ۏ؋K肪Ĉ܂܂̌`Ń\[
 *      XR[hɊ܂܂Ă邱ƁD
 *  (2) {\tgEFACCu`ȂǁC̃\tgEFAJɎg
 *      pł`ōĔzzꍇɂ́CĔzzɔhLgip
 *      ҃}jAȂǁjɁCL̒쌠\C̗pщL
 *      ̖ۏ؋Kfڂ邱ƁD
 *  (3) {\tgEFAC@ɑgݍނȂǁC̃\tgEFAJɎg
 *      płȂ`ōĔzzꍇɂ́Ĉꂩ̏𖞂
 *      ƁD
 *    (a) ĔzzɔhLgip҃}jAȂǁjɁCL̒
 *        쌠\C̗pщL̖ۏ؋Kfڂ邱ƁD
 *    (b) Ĕzž`ԂCʂɒ߂@ɂāCTOPPERSvWFNg
 *        񍐂邱ƁD
 *  (4) {\tgEFA̗pɂ蒼ړI܂͊ԐړIɐ邢Ȃ鑹
 *      QCL쌠҂TOPPERSvWFNgƐӂ邱ƁD
 * 
 *  {\tgEFÁCۏ؂Œ񋟂Ă̂łDL쌠҂
 *  TOPPERSvWFNǵC{\tgEFAɊւāC̓Kp\
 *  ܂߂āCȂۏ؂sȂD܂C{\tgEFA̗pɂ蒼
 *  ړI܂͊ԐړIɐȂ鑹QɊւĂC̐ӔC𕉂ȂD
 * 
 *  
 */
 
 
 
#ifndef _BOARD_CONFIG_H_
#define _BOARD_CONFIG_H_

/*
 * ADSP-BF533ɈˑA{[hւ̎ɂČ܂p[^
 * Œ`B
 */


/*
 * ǂ̂悤ȃNbN͂ɂΉł悤AȉCSEL, SSEL, MSEL̒l
 * ƃNbN͎g(Hz)w肷BPLL̃vOsys_config.c
 * sys_initialize()֐ōsB
 *
 * CSELVAL1,2,4,8̒IԁBCLKIN̒PʂHz
 */
 
#define CSELVAL 1
#define SSELVAL 5
#define MSELVAL 22
#define CLKIN 27000000

/*
 * TICp^C}[̑I
 * USE_TIC_COREdefineƁACORE^C}[gp
 * RgAEgƁAGP_TIMER_2gp
 *
 * CORE^C}[wakeupM𐶐Ȃ߁AfBXpb`
 * idle߂gCORE^C}[Cxg҂ƂłȂB
 * ̂߁AUSE_TIC_COREgƃfBXpb`idle߂
 * g킸Ɋ荞ݔ|[Oő҂B͏d͂
 * _ŕsłB
 *
 */
//#define USE_TIC_CORE

/*
 * n[hEFAEG[荞݂̋
 * USE_HW_ERRORdefineƁAINHNO_HW_ERRORg悤
 * ȂB錾ɂ̃nho^Ǝs~B
 *
 */
//#define USE_HW_ERROR


/*
 * s֐̎gp
 * 
 * }N USE_RUNTIME_INIT `ƁAstart.asm̂Ȃ _mi_initialize
 * ĂяoB̊֐̓m[u[g[hŋNƂɂ̂ݕKvɂȂ̂
 * ʏ USE_RUNTIME_INITgKv͂ȂB
 * ڍׂADIEE239ɏڂBhttp://tinyurl.com/2hpbk (tinyURL)
 * 
*/
#define USE_RUNTIME_INIT

/*
 * ǗO荞݂̐錾
 * 
 * }NUNMANAGED_INT͊ǗO荞݂錾B
 * }N16rbg̃rbg}bvɂȂĂAǗOɂȂ
 * CxgɑΉrbg1ɂBႦ0x0100IV8ǗO
 * ɂB錾ȂꍇAǗO荞݂͂ȂƂĈB
 * ǗO荞݂ɂł̂IVG13 - IVHW łB
 * 
*/
//#define UNMANAGED_INT 0x0100

/*
 * C++֘Apӂ
 * 
 * }NINIT_C_PLUS_PLUS`ƁAC++p̃e[u
 * R[hsB܂AC++p̃e[u錾
 * 
*/
//#define INIT_C_PLUS_PLUS

/*
 *  NbZ[W̃^[QbgVXe
 */
#define	TARGET_NAME	"ADSP-BF533"


#endif // _BOARD_CONFIG_H_

==> blackfin-vdsp_1.3.0.zip: blackfin-vdsp/bf533/board_config.h <==
/*
 *  TOPPERS/JSP Kernel
 *      Toyohashi Open Platform for Embedded Real-Time Systems/
 *      Just Standard Profile Kernel
 * 
 *  Copyright (C) 2000-2003 by Embedded and Real-Time Systems Laboratory
 *                              Toyohashi Univ. of Technology, JAPAN
 *
 *  TOPPERS/JSP for Blackfin
 *
 *  Copyright (C) 2004 by Suikan
 *  Copyright (C) 2004 by Ujinosuke
 *
 *  L쌠҂́Cȉ (1)`(4) ̏CFree Software Foundation 
 *  ɂČ\Ă GNU General Public License  Version 2 ɋL
 *  qĂ𖞂ꍇɌC{\tgEFAi{\tgEFA
 *  ς̂܂ށDȉjgpEEρEĔzziȉC
 *  pƌĂԁj邱Ƃ𖳏ŋD
 *  (1) {\tgEFA\[XR[ȟ`ŗpꍇɂ́CL̒
 *      \C̗pщL̖ۏ؋K肪Ĉ܂܂̌`Ń\[
 *      XR[hɊ܂܂Ă邱ƁD
 *  (2) {\tgEFACCu`ȂǁC̃\tgEFAJɎg
 *      pł`ōĔzzꍇɂ́CĔzzɔhLgip
 *      ҃}jAȂǁjɁCL̒쌠\C̗pщL
 *      ̖ۏ؋Kfڂ邱ƁD
 *  (3) {\tgEFAC@ɑgݍނȂǁC̃\tgEFAJɎg
 *      płȂ`ōĔzzꍇɂ́Ĉꂩ̏𖞂
 *      ƁD
 *    (a) ĔzzɔhLgip҃}jAȂǁjɁCL̒
 *        쌠\C̗pщL̖ۏ؋Kfڂ邱ƁD
 *    (b) Ĕzž`ԂCʂɒ߂@ɂāCTOPPERSvWFNg
 *        񍐂邱ƁD
 *  (4) {\tgEFA̗pɂ蒼ړI܂͊ԐړIɐ邢Ȃ鑹
 *      QCL쌠҂TOPPERSvWFNgƐӂ邱ƁD
 * 
 *  {\tgEFÁCۏ؂Œ񋟂Ă̂łDL쌠҂
 *  TOPPERSvWFNǵC{\tgEFAɊւāC̓Kp\
 *  ܂߂āCȂۏ؂sȂD܂C{\tgEFA̗pɂ蒼
 *  ړI܂͊ԐړIɐȂ鑹QɊւĂC̐ӔC𕉂ȂD
 * 
 *  
 */
 
 
 
#ifndef _BOARD_CONFIG_H_
#define _BOARD_CONFIG_H_

/*
 * ADSP-BF533ɈˑA{[hւ̎ɂČ܂p[^
 * Œ`B
 */


/*
 * ǂ̂悤ȃNbN͂ɂΉł悤AȉCSEL, SSEL, MSEL̒l
 * ƃNbN͎g(Hz)w肷BPLL̃vOsys_config.c
 * sys_initialize()֐ōsB
 *
 * CSELVAL1,2,4,8̒IԁBCLKIN̒PʂHz
 */
 
#define CSELVAL 1
#define SSELVAL 5
#define MSELVAL 22
#define CLKIN 27000000

/*
 * TICp^C}[̑I
 * USE_TIC_COREdefineƁACORE^C}[gp
 * RgAEgƁAGP_TIMER_2gp
 *
 * CORE^C}[wakeupM𐶐Ȃ߁AfBXpb`
 * idle߂gCORE^C}[Cxg҂ƂłȂB
 * ̂߁AUSE_TIC_COREgƃfBXpb`idle߂
 * g킸Ɋ荞ݔ|[Oő҂B͏d͂
 * _ŕsłB
 *
 */
//#define USE_TIC_CORE

/*
 * n[hEFAEG[荞݂̋
 * USE_HW_ERRORdefineƁAINHNO_HW_ERRORg悤
 * ȂB錾ɂ̃nho^Ǝs~B
 *
 */
//#define USE_HW_ERROR


/*
 * s֐̎gp
 * 
 * }N USE_RUNTIME_INIT `ƁAstart.asm̂Ȃ _mi_initialize
 * ĂяoB̊֐̓m[u[g[hŋNƂɂ̂ݕKvɂȂ̂
 * ʏ USE_RUNTIME_INITgKv͂ȂB
 * ڍׂADIEE239ɏڂBhttp://tinyurl.com/2hpbk (tinyURL)
 * 
*/
#define USE_RUNTIME_INIT

/*
 * J[lǗO荞݂̐錾
 * 
 * }NUNMANAGED_INT̓J[lǗO荞݂錾B
 * }N16rbg̃rbg}bvɂȂĂAȉɂp^[
 * ̂ЂƂgBȂAǂ̂悤ȃp^[IłNMI͊ǗO
 * ݂ƂĈB
 * UNMANAGED_INT錾ȂꍇANMIǗO݂ƂĈB
 * 
*/
//#define UNMANAGED_INT 0x0020			// IVHWJ[lǗO.
//#define UNMANAGED_INT 0x0060			// IVTMRIVHWJ[lǗO.
//#define UNMANAGED_INT 0x00E0			// IVG7, IVTMRIVHWJ[lǗO.
//#define UNMANAGED_INT 0x01E0			// IVG8 ... IVG7, IVTMRIVHWJ[lǗO.
//#define UNMANAGED_INT 0x03E0			// IVG9 ... IVG7, IVTMRIVHWJ[lǗO.
//#define UNMANAGED_INT 0x07E0			// IVG10 ... IVG7, IVTMRIVHWJ[lǗO.
//#define UNMANAGED_INT 0x0FE0			// IVG11 ... IVG7, IVTMRIVHWJ[lǗO.
//#define UNMANAGED_INT 0x1FE0			// IVG12 ... IVG7, IVTMRIVHWJ[lǗO.
//#define UNMANAGED_INT 0x3FE0			// IVG13 ... IVG7, IVTMRIVHWJ[lǗO.

/*
 * C++֘Apӂ
 * 
 * }NINIT_C_PLUS_PLUS`ƁAC++p̃e[u
 * R[hsB܂AC++p̃e[u錾
 * 
*/
//#define INIT_C_PLUS_PLUS

/*
 *  NbZ[W̃^[QbgVXe
 */
#define	TARGET_NAME	"ADSP-BF533"


/*
 *  VA|[g̒`
 *  TNUM_SIOP_XXX́AUART̎ʂƂɐ錾B
 *  TNUM_SIOP_UARTBF533UART̂APDICgṕB
 *  BF533UARTЂƂĂȂ̂ŁA10錾B
 *  TNUM_PORT́ATNUM_SIOP_XXX̂AGDICgp̂̑aB
 *  uart.cŎgB
 */
#define TNUM_PORT	1		/* GDICT|[gVA|[g̐ */
#define TNUM_SIOP_UART	1	/* PIDCT|[gVA|[g̐ */

/*
 *  VA|[gԍɊւ`
 *  O^XNVA|[ggȂꍇ͖ĂB
 */
#define	LOGTASK_PORTID	1	/* VXeOɗpVA|[gԍ */


#endif // _BOARD_CONFIG_H_
